@@ -17,7 +17,7 @@ use Params::Validate qw/validate_with SCALAR ARRAYREF CODEREF UNDEF
 use Acme::Damn       qw/damn/;
 use Carp::Clan       qw[^(DBIx::DataModel::|SQL::Abstract)];
 
-use SQL::Abstract::More 1.32;
+use SQL::Abstract::More 1.33;
 use Try::Tiny;
 
 use namespace::clean;
@@ -334,12 +334,23 @@ while (my ($local, $remote) = each %accessor_map) {
     ref $self or $self = $self->singleton;
 
     my $meta_source = $self->metadm->$remote(@_) or return;
-    my $cs_class = $self->metadm->connected_source_class;
-    load $cs_class;
-    return $cs_class->new($meta_source, $self);
+    my $obj = bless {__schema => $self}, $meta_source->class;
+    return $obj;
   }
 }
 
+# while (my ($local, $remote) = each %accessor_map) {
+#   no strict 'refs';
+#   *$local = sub {
+#     my $self = shift;
+#     ref $self or $self = $self->singleton;
+
+#     my $meta_source = $self->metadm->$remote(@_) or return;
+#     my $cs_class = $self->metadm->connected_source_class;
+#     load $cs_class;
+#     return $cs_class->new($meta_source, $self);
+#   }
+# }
 
 #----------------------------------------------------------------------
 # UTILITY FUNCTIONS (PRIVATE)
